Intel® Threading Building Blocks. Samples on task_group interface

# Intel® Threading Building Blocks
Samples on `task_group` interface

This directory has examples of how to use `task_group` interface.

Directories

Sudoku
  Compute all solutions for a Sudoku board.

Up to parent directory

Legal Information:

Intel and the Intel logo are trademarks of Intel Corporation in the U.S. and/or other countries.
* Other names and brands may be claimed as the property of others.
© 2020, Intel Corporation